@@ -5,7 +5,7 @@ use utf8;
 
 package Neo4j::Driver::Session;
 # ABSTRACT: Context of work for database interactions
-$Neo4j::Driver::Session::VERSION = '0.30';
+$Neo4j::Driver::Session::VERSION = '0.31';
 
 use Carp qw();
 our @CARP_NOT = qw(Neo4j::Driver);
@@ -128,7 +128,7 @@ Neo4j::Driver::Session - Context of work for database interactions
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -195,11 +195,11 @@ commit the transaction.
 
 =head2 server
 
- $address = $summary->server->address;
- $version = $summary->server->version;
+ $address = $session->server->address;
+ $version = $session->server->agent;
 
 Obtain the L<ServerInfo|Neo4j::Driver::ServerInfo>, consisting of
-the host, port and Neo4j version.
+the host, port, protocol and Neo4j version.
 
 =head1 EXPERIMENTAL FEATURES
 
